@@ -288,12 +288,14 @@ Request example
         scheme = self.data.get('schemes', ['https'])[0]
         host = self.data.get('host', 'example.com')
         consumes = verbDef.get('consumes', ['application/json'])[0]
-        data = json.dumps(objOrArray, indent=2).replace("\n", "\\\n")
+        data = json.dumps(objOrArray, indent=2)
 
         code = f'''curl {scheme}://{host}{self.path} \\
 --header "Content-Type: {consumes}" \\
 --request {verb.upper()} \\
---data '{data}'
+--data @- &lt;&lt;'EOF'
+{data}
+EOF
 '''
 
         out = f'''
@@ -413,8 +415,6 @@ Request code example
     def parameters(self, parameters):
         out = []
         for p in parameters:
-            where = p.get('in', '')
-            schema = p.get('schema')
             out.append(self.parameter(p, []))
     
         return self.parametersTable(''.join(out))
